@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
 use Dist::Zilla 6.0;
 
@@ -21,13 +21,12 @@ use Dist::Zilla::Plugin::CheckSelfDependency;
 use Dist::Zilla::Plugin::CheckStrictVersion;
 use Dist::Zilla::Plugin::CheckVersionIncrement;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
-use Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent;
 use Dist::Zilla::Plugin::DROLSKY::Contributors;
 use Dist::Zilla::Plugin::DROLSKY::License;
 use Dist::Zilla::Plugin::DROLSKY::TidyAll;
-use Dist::Zilla::Plugin::DROLSKY::VersionProvider;
 use Dist::Zilla::Plugin::DROLSKY::WeaverConfig;
-use Dist::Zilla::Plugin::GenerateFile::FromShareDir;
+use Dist::Zilla::Plugin::EnsureChangesHasContent 0.02;
+use Dist::Zilla::Plugin::GenerateFile::FromShareDir 0.013;
 use Dist::Zilla::Plugin::Git::Check;
 use Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts;
 use Dist::Zilla::Plugin::Git::Commit;
@@ -64,7 +63,7 @@ use Dist::Zilla::Plugin::Test::ReportPrereqs;
 use Dist::Zilla::Plugin::Test::Synopsis;
 use Dist::Zilla::Plugin::Test::TidyAll 0.04;
 use Dist::Zilla::Plugin::Test::Version;
-use Parse::PMFile;
+use Dist::Zilla::Plugin::VersionFromMainModule 0.02;
 use Path::Iterator::Rule;
 
 use Moose;
@@ -331,7 +330,7 @@ sub _build_exclude {
 sub _basic_plugins {
 
     # These are a subset of the @Basic bundle except for CheckVersionIncrement
-    # and DROLSKY::VersionProvider.
+    # and VersionFromMainModule.
     qw(
         ManifestSkip
         License
@@ -342,7 +341,7 @@ sub _basic_plugins {
         TestRelease
         ConfirmRelease
         UploadToCPAN
-        DROLSKY::VersionProvider
+        VersionFromMainModule
     );
 }
 
@@ -559,12 +558,10 @@ sub _prompt_if_stale_plugin {
                 check_authordeps  => 1,
                 skip              => [
                     qw(
-                        Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent
                         Dist::Zilla::Plugin::DROLSKY::Contributors
                         Dist::Zilla::Plugin::DROLSKY::Git::CheckFor::CorrectBranch
                         Dist::Zilla::Plugin::DROLSKY::License
                         Dist::Zilla::Plugin::DROLSKY::TidyAll
-                        Dist::Zilla::Plugin::DROLSKY::VersionProvider
                         Pod::Weaver::PluginBundle::DROLSKY
                         )
                 ],
@@ -719,8 +716,8 @@ sub _release_check_plugins {
         qw(
             CheckSelfDependency
             CheckPrereqsIndexed
-            DROLSKY::CheckChangesHasContent
             DROLSKY::Git::CheckFor::CorrectBranch
+            EnsureChangesHasContent
             Git::CheckFor::MergeConflicts
             ),
     );
@@ -800,7 +797,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -811,7 +808,7 @@ version 0.78
 
     [@DROLSKY]
     dist = My-Module
-    ; Fefault is MakeMaker - or set it to ModuleBuild
+    ; Default is MakeMaker - or set it to ModuleBuild
     make_tool = MakeMaker
     ; These files won't be added to tarball
     exclude_files = ...
@@ -868,8 +865,7 @@ This is more or less equivalent to the following F<dist.ini>:
     [TestRelease]
     [ConfirmRelease]
     [UploadToCPAN]
-    ; Opens up the main module and finds a $VERSION
-    [DROLSKY::VersionProvider]
+    [VersionFromMainModule]
 
     [Authority]
     ; Configured by setting authority for the bundle
@@ -948,12 +944,10 @@ This is more or less equivalent to the following F<dist.ini>:
     check_all_plugins = 1
     check_all_prereqs = 1
     check_authordeps  = 1
-    skip = Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent
     skip = Dist::Zilla::Plugin::DROLSKY::Contributors
     skip = Dist::Zilla::Plugin::DROLSKY::Git::CheckFor::CorrectBranch
     skip = Dist::Zilla::Plugin::DROLSKY::License
     skip = Dist::Zilla::Plugin::DROLSKY::TidyAll
-    skip = Dist::Zilla::Plugin::DROLSKY::VersionProvider
     skip = Pod::Weaver::PluginBundle::DROLSKY
 
     [Test::Pod::Coverage::Configurable]
@@ -1031,10 +1025,7 @@ This is more or less equivalent to the following F<dist.ini>:
     [DROLSKY::License]
 
     [CheckPrereqsIndexed]
-
-    ; More or less like Dist::Zilla::Plugin::CheckChangesHasContent but uses
-    ; CPAN::Changes to parse the Changes file.
-    [DROLSKY::CheckChangesHasContent]
+    [EnsureChangesHasContent]
 
     ; Just like Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch except that
     ; it allows releases from any branch for TRIAL
@@ -1078,11 +1069,14 @@ This is more or less equivalent to the following F<dist.ini>:
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-DROLSKY>
-(or L<bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org|mailto:bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/autarch/Dist-Zilla-PluginBundle-DROLSKY/issues>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
+=head1 SOURCE
+
+The source code repository for Dist-Zilla-PluginBundle-DROLSKY can be found at L<https://github.com/autarch/Dist-Zilla-PluginBundle-DROLSKY>.
+
 =head1 DONATIONS
 
 If you'd like to thank me for the work I've done on this module, please
@@ -1112,10 +1106,13 @@ Mark Fowler <mark@twoshortplanks.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2013 - 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
