@@ -3,10 +3,11 @@ package Pod::Weaver::PluginBundle::DROLSKY;
 use strict;
 use warnings;
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
 use namespace::autoclean -also => ['_exp'];
 
+use Dist::Zilla::Plugin::PodWeaver;
 use Module::Runtime qw( use_module );
 use PadWalker qw( peek_sub );
 use Pod::Elemental::Transformer::List;
@@ -38,31 +39,22 @@ sub configure {
     # containing plugin specifications. The goal is to make this look as close
     # to what weaver.ini looks like as possible.
 
-    # I wouldn't have to do this ugliness if I could have some configuration values passed in from weaver.ini or
-    # the [PodWeaver] plugin's use of config_plugin (where I could define a 'licence' option)
+    # I wouldn't have to do this ugliness if I could have some configuration
+    # values passed in from weaver.ini or the [PodWeaver] plugin's use of
+    # config_plugin (where I could define a 'licence' option)
+
+    ## no critic (Subroutines::ProhibitCallsToUnexportedSubs)
     my $podweaver_plugin
         = ${ peek_sub( \&Dist::Zilla::Plugin::PodWeaver::weaver )->{'$self'}
         };
-
     my $zilla = $podweaver_plugin->zilla;
-    my $bundle_prefix;
-    for my $name ( map { $_->plugin_name } @{ $zilla->plugins } ) {
 
-        # We want a plugin that was added by our bundle.
-        next unless ($bundle_prefix) = $name =~ m{^(.+)/};
-        last;
-    }
-
-    my $license_plugin = $zilla->plugin_named( $bundle_prefix . '/License' );
+    my $license_plugin
+        = $zilla->plugin_named( '@' . $self->_prefix . '/License' );
     my $license_filename
         = $license_plugin ? $license_plugin->filename : 'LICENSE';
 
-    my $config
-        = $zilla->plugin_named( $bundle_prefix . '/DROLSKY::WeaverConfig' );
-    my $include_donations = $zilla->copyright_holder =~ /Rolsky/
-        && $config->include_donations_pod;
-
-    my @config = (
+    my @weaver_config = (
         '@CorePrep',
         [ '-SingleEncoding' => { encoding => 'UTF-8' } ],
         [ '-Transformer' => List     => { transformer => 'List' } ],
@@ -80,43 +72,7 @@ sub configure {
         [ 'Collect' => 'TYPES' => { command => 'type' } ],
         'Leftovers',
         [ 'Region' => 'postlude' ],
-        [
-            'GenerateSection' => 'generate SUPPORT' => {
-                title            => 'SUPPORT',
-                main_module_only => 0,
-                text             => [
-                    <<'SUPPORT',
-{{ join("\n\n",
-    ($bugtracker_email && $bugtracker_email =~ /rt\.cpan\.org/)
-    ? "Bugs may be submitted through L<the RT bug tracker|$bugtracker_web>\n(or L<$bugtracker_email|mailto:$bugtracker_email>)."
-    : $bugtracker_web
-    ? "Bugs may be submitted through L<$bugtracker_web>."
-    : (),
-
-    $distmeta->{resources}{x_MailingList} ? 'There is a mailing list available for users of this distribution,' . "\nL<mailto:" . $distmeta->{resources}{x_MailingList} . '>.' : (),
-
-    $distmeta->{resources}{x_IRC}
-        ? 'This distribution also has an IRC channel at' . "\nL<"
-            . do {
-                # try to extract the channel
-                if (my ($network, $channel) = ($distmeta->{resources}{x_IRC} =~ m!(?:://)?(\w+(?:\.\w+)*)/?(#\w+)!)) {
-                    'C<' . $channel . '> on C<' . $network . '>|' . $distmeta->{resources}{x_IRC}
-                }
-                else {
-                    $distmeta->{resources}{x_IRC}
-                }
-            }
-            . '>.'
-        : (),
-
-    ($distmeta->{x_authority} // '') eq 'cpan:DROLSKY'
-    ? q{I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.}
-    : (),
-) }}
-SUPPORT
-                ]
-            },
-        ],
+        [ $self->_support_section ],
         [
             'AllowOverride' => 'allow override SUPPORT' => {
                 header_re      => '^(SUPPORT|BUGS)\b',
@@ -124,16 +80,122 @@ SUPPORT
                 match_anywhere => 0,
             },
         ],
+        [ $self->_source_section ],
     );
 
-    if ($include_donations) {
-        push @config, [
-            'GenerateSection' => 'generate DONATIONS' => {
-                title            => 'DONATIONS',
-                main_module_only => 1,
-                is_template      => 0,
-                text             => [
-                    <<'DONATIONS',
+    my $config
+        = $zilla->plugin_named(
+        '@' . $self->_prefix . '/DROLSKY::WeaverConfig' );
+    push @weaver_config, [ $self->_donation_section ]
+        if $zilla->copyright_holder =~ /Rolsky/
+        && $config->include_donations_pod;
+
+    push @weaver_config, (
+        'Authors',
+        [ 'Contributors' => { ':version' => '0.008' } ],
+        [
+            'Legal' => {
+                ':version'   => '4.011',
+                header       => 'COPYRIGHT AND ' . $license_filename,
+                license_file => $license_filename,
+            }
+        ],
+        [ 'Region' => 'footer' ],
+    );
+
+    return @weaver_config;
+}
+
+sub _support_section {
+    my $self = shift;
+
+    # It'd be simpler to just get the dist meta stuff right now but the pod
+    # weaver bundle is configured before this is ready, leading to an endless
+    # loop in Dist::Zilla::_build_distmeta (a bug in DZ? maybe).
+    my $template = <<'SUPPORT';
+{{
+join "\n\n", (
+    (
+        $bugtracker_email
+        ? "Bugs may be submitted at L<$bugtracker_web> or via email to L<$bugtracker_email|mailto:$bugtracker_email>."
+        : $bugtracker_web ? "Bugs may be submitted at L<$bugtracker_web>."
+        : (),
+        ),
+    (
+        $distmeta->{resources}{x_MailingList}
+        ? 'There is a mailing list available for users of this distribution,'
+            . "\nL<mailto:"
+            . $distmeta->{resources}{x_MailingList} . '>.'
+        : (),
+    ),
+    (
+        $distmeta->{resources}{x_IRC}
+        ? 'This distribution also has an IRC channel at' . "\nL<" . do {
+
+            # try to extract the channel
+            if (
+                my ( $network, $channel ) = (
+                    $distmeta->{resources}{x_IRC}
+                        =~ m!(?:://)?(\w+(?:\.\w+)*)/?(#\w+)!
+                )
+                ) {
+                'C<'
+                    . $channel
+                    . '> on C<'
+                    . $network . '>|'
+                    . $distmeta->{resources}{x_IRC};
+            }
+            else {
+                $distmeta->{resources}{x_IRC};
+            }
+            }
+            . '>.'
+        : (),
+    ),
+    (
+        ( $distmeta->{x_authority} // '' ) eq 'cpan:DROLSKY'
+        ? q{I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.}
+        : (),
+    ),
+    )
+}}
+SUPPORT
+
+    return (
+        'GenerateSection' => 'generate SUPPORT' => {
+            title            => 'SUPPORT',
+            main_module_only => 0,
+            is_template      => 1,
+            text             => [$template],
+        },
+    );
+}
+
+sub _source_section {
+    my $self = shift;
+
+    my $template = <<'SOURCE';
+The source code repository for {{ $name }} can be found at L<{{ $repository_web }}>.
+SOURCE
+
+    return (
+        'GenerateSection' => 'generate SOURCE' => {
+            title            => 'SOURCE',
+            main_module_only => 0,
+            is_template      => 1,
+            text             => [$template],
+        },
+    );
+}
+
+sub _donation_section {
+    return (
+        'GenerateSection' => 'generate DONATIONS' => {
+            title            => 'DONATIONS',
+            main_module_only => 1,
+            is_template      => 0,
+            text             => [
+                <<'DONATIONS',
 If you'd like to thank me for the work I've done on this module, please
 consider making a "donation" to me via PayPal. I spend a lot of free time
 creating free software, and would appreciate any support you'd care to offer.
@@ -149,24 +211,9 @@ on free software full time (let's all have a chuckle at that together).
 To donate, log into PayPal and send money to autarch@urth.org, or use the
 button at L<http://www.urth.org/~autarch/fs-donation.html>.
 DONATIONS
-                ]
-            },
-        ];
-    }
-
-    push @config, (
-        'Authors',
-        [ 'Contributors' => { ':version' => '0.008' } ],
-        [
-            'Legal' => {
-                ':version' => '4.011',
-                header     => 'COPYRIGHT AND ' . $license_filename
-            }
-        ],
-        [ 'Region' => 'footer' ],
+            ]
+        },
     );
-
-    return @config;
 }
 
 sub mvp_bundle_config {
@@ -251,7 +298,7 @@ Pod::Weaver::PluginBundle::DROLSKY - A plugin bundle for pod woven by DROLSKY
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -429,21 +476,27 @@ L<Dist::Zilla::PluginBundle::DROLSKY>
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-DROLSKY>
-(or L<bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org|mailto:bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/autarch/Dist-Zilla-PluginBundle-DROLSKY/issues>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
+=head1 SOURCE
+
+The source code repository for Dist-Zilla-PluginBundle-DROLSKY can be found at L<https://github.com/autarch/Dist-Zilla-PluginBundle-DROLSKY>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2013 - 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
